@@ -22,11 +22,13 @@ from azure.mgmt.containerinstance.models import (
     OperatingSystemTypes,
 )
 
-from taz.auth import UserAssignedIdentity, ClientSecretAuthentication, GenericClient
 import json
 import os
 from azure.common.credentials import ServicePrincipalCredentials
 
+from taz.auth import UserAssignedIdentity, ClientSecretAuthentication, GenericClient
+from taz.exception import ContainerAlreadyExistsException
+
 
 class SimpleContainerGroup:
 
@@ -52,7 +54,8 @@ class SimpleContainerGroup:
         - tags (dict[str, str]): Azure tags
         - state (string): state of container group 
         (Accessed if already created, Provisionned if it is prepared, and Created if it is created)
-        - protected (True, bool): display env vars values or not
+        - protected (bool): display env vars values or not
+        - identity_name (str): name of user managed identity
     """
 
     def __init__(
@@ -66,6 +69,7 @@ class SimpleContainerGroup:
         cpus=1,
         mem=1,
         command=None,
+        identity_name=None,
         identity=None,
         restart_policy="Never",
         env_vars=[],
@@ -86,6 +90,7 @@ class SimpleContainerGroup:
             - identity (None, taz.auth.UserAssignedIdentity, optionnal): User managed identity to affect
             - restart_policy ("Never", str, optionnal): set restart policy of container
             - env_vars (None, dict, optionnal):  environment variables dictionnary to set
+            - identity_name (None, str, optionnal): user managed identity by name (identity parameter ignored if set)
         """
 
         self.generic_client = GenericClient(
@@ -96,6 +101,7 @@ class SimpleContainerGroup:
         # Required parameters
         self.name = name
         self.resource_group_name = resource_group_name
+        self.subscription_id = subscription_id
 
         # Optionnal parameters
         self.location = location
@@ -109,21 +115,34 @@ class SimpleContainerGroup:
         self.group = None
         self.instances = []
         self.tags = tags
-        self.state = "Provisionned"
         self.protected = True
         self.env_vars = []
+        self.identity_name = identity_name
 
         if env_vars:
             self.set_env_vars(env_vars)
 
-        if not self.image:
+        try:
+            # container group already exists
             self._get_group()
+            self.cpus = 0
+            self.mem = 0
+            self.state = "Accessed"
+        except:
+
+            # container group provisionned (before create methos call)
+            self.state = "Provisionned"
+            if self.identity_name:
+                self.set_identity_by_name(self.identity_name)
 
     def _get_group(self):
-        self.state = "Accessed"
         self.group = self.client.container_groups.get(
             self.resource_group_name, self.name
         )
+
+        self.restart_policy = self.group.restart_policy
+        self.identity = self.group.identity
+
         for instance in self.group.containers:
             self.instances.append(instance)
 
@@ -174,6 +193,21 @@ class SimpleContainerGroup:
         """
         self.identity = identity.get_container_group_identity()
 
+    def set_identity_by_name(self, identity_name, resource_group=None):
+        """
+        set identity by identity name instead of taz.auth.UserAssignedIdentity object (set_identity method)
+
+        Args:
+            - identity_name (str): user assigned identity name to affect
+            - resource_group(None, str, optionnal): if not set, same as container group
+        """
+        if not resource_group:
+            resource_group = self.resource_group_name
+        self.identity_name = identity_name
+        self.identity = UserAssignedIdentity(
+            resource_group, self.identity_name, subscription_id=self.subscription_id
+        )
+
     def set_command(self, command):
         """
         set command entry point of container
@@ -188,6 +222,9 @@ class SimpleContainerGroup:
         Create the container group and instance
         """
 
+        if self.state == "Accessed":
+            raise (ContainerAlreadyExistsException(self.name))
+
         # Configure the container
         container_resource_requests = ResourceRequests(
             memory_in_gb=self.mem, cpu=self.cpus
@@ -301,14 +338,40 @@ class SimpleContainerGroup:
                             event.message,
                         )
                     )
+                command = instance.command
+                ports = instance.ports
                 state = instance.instance_view.current_state.state
+                start_time = str(instance.instance_view.current_state.start_time)
+                finish_time = str(instance.instance_view.current_state.finish_time)
+                exit_code = instance.instance_view.current_state.exit_code
+                detail_status = instance.instance_view.current_state.detail_status
+                memory = instance.resources.requests.memory_in_gb
+                cpus = instance.resources.requests.cpu
+
             except:
                 state = "unknown"
+                start_time = "unknown"
+                finish_time = "unknown"
+                exit_code = "unknown"
+                detail_status = "unknown"
+                ports = []
+                command = "unknown"
+                cpus = "unknown"
+                memory = "unknown"
+
             instances.append(
                 {
                     "name": instance.name,
                     "image": instance.image,
+                    "memory": memory,
+                    "cpus": cpus,
+                    "command": command,
+                    "ports": ports,
                     "state": state,
+                    "start_time": start_time,
+                    "finish_time": finish_time,
+                    "exit_code": exit_code,
+                    "detail_status": detail_status,
                     "events": events,
                     "vars": vars,
                 }
@@ -322,12 +385,13 @@ class SimpleContainerGroup:
         return json.dumps(
             {
                 "name": self.name,
+                "identity": str(self.identity),
                 "cpus": self.cpus,
-                "mem": self.mem,
+                "memory": self.mem,
                 "restart_policy": self.restart_policy,
-                "command": self.command,
                 "state": self.state,
                 "group_name": group_name,
                 "instances": instances,
-            }
+            },
+            indent=4,
         )
